"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vue_1 = require("vue");
const helpers_1 = require("../../helpers/index.cjs");
exports.default = (0, vue_1.defineComponent)({
    name: 'IIcon',
    props: {
        /**
         * @description The icon to be displayed
         * @type String
         * @default
         */
        name: {
            type: String,
            default: ''
        },
        /**
         * @description The size variant of the icon
         * @type sm | md | lg
         * @default md
         */
        size: {
            type: String,
            default: ''
        }
    },
    setup(props) {
        const controller = (0, vue_1.inject)('inklineIcons', {
            icons: {}
        });
        const iconName = (0, vue_1.computed)(() => (0, helpers_1.toCamelCase)(props.name));
        const icon = (0, vue_1.computed)(() => controller.icons[iconName.value]);
        const classes = (0, vue_1.computed)(() => ({
            'inkline-icon': true,
            [`-${props.size}`]: Boolean(props.size)
        }));
        (0, vue_1.onMounted)(() => {
            if (iconName.value && !controller.icons[iconName.value]) {
                console.error(`The icon ${iconName.value} is not registered.`);
            }
        });
        return () => (0, vue_1.h)('svg', {
            class: classes.value,
            ...icon.value?.attributes
        }, (0, helpers_1.renderChildren)(icon.value?.children || []));
    }
});
//# sourceMappingURL=script.cjs.map